# Holographic

It's annoying and unsustainable to author resusable code in a python notebook. This problem is exacerbated when the notebook system is not running in a local development environment or otherwise does not have access to the same filesystem as the IDEs which the author would prefer to use. So, wouldn't it be nice if you could develop your code wherever you wanted, and as long as that place had an internet connection (and as long as your notebook has an internet connection) you could create a read-only copy of your code in the notebook environment, holographic code if you will, and have the best of both worlds: a fully-featured authoring experience with static-analysis tools, multi-select, etc. and the rich interactive runtime experience of a notebook environment.